@@ -19,15 +19,17 @@
 
 #include "amarok_export.h"
 #include "amarokurls/BookmarkGroup.h"
-#include "core/meta/Meta.h"
+#include "core/meta/forward_declarations.h"
 #include "core/playlists/Playlist.h"
 #include "core/podcasts/PodcastMeta.h"
-#include "core/collections/QueryMaker.h"
 
 #include <QList>
-#include <QMap>
 #include <QMimeData>
 
+namespace Collections {
+    class QueryMaker;
+}
+
 class AMAROK_EXPORT AmarokMimeData : public QMimeData
 {
     Q_OBJECT
@@ -44,10 +46,10 @@ class AMAROK_EXPORT AmarokMimeData : public QMimeData
         static const QString BOOKMARKGROUP_MIME;
 
         AmarokMimeData();
-        virtual ~AmarokMimeData();
+        ~AmarokMimeData() override;
 
-        virtual QStringList formats() const;
-        virtual bool hasFormat( const QString &mimeType ) const;
+        QStringList formats() const override;
+        bool hasFormat( const QString &mimeType ) const override;
 
         Meta::TrackList tracks() const;
         void setTracks( const Meta::TrackList &tracks );
@@ -88,16 +90,16 @@ class AMAROK_EXPORT AmarokMimeData : public QMimeData
          */
         void startQueries();
 
-    signals:
+    Q_SIGNALS:
         void trackListSignal( Meta::TrackList ) const;
 
-    public slots:
+    public Q_SLOTS:
         void getTrackListSignal() const;
 
     protected:
-        virtual QVariant retrieveData( const QString &mimeType, QVariant::Type type ) const;
+        QVariant retrieveData( const QString &mimeType, QVariant::Type type ) const override;
 
-    private slots:
+    private Q_SLOTS:
         void newResultReady( const Meta::TrackList &tracks );
         void queryDone();
 
