@@ -33,17 +33,17 @@ class LastfmReadLabelCapability : public Capabilities::ReadLabelCapability
 {
     Q_OBJECT
     public:
-        LastfmReadLabelCapability( Meta::Track *track );
-        virtual void fetchLabels();
-        virtual void fetchGlobalLabels();
-        virtual QStringList labels();
+        explicit LastfmReadLabelCapability( Meta::Track *track );
+        void fetchLabels() override;
+        void fetchGlobalLabels() override;
+        QStringList labels() override;
 
     private:
         QStringList m_labels;
         Meta::TrackPtr m_track;
         QNetworkReply *m_job;
 
-    private slots:
+    private Q_SLOTS:
         void onTagsFetched();
 };
 }
