@@ -19,11 +19,8 @@
 #ifndef AMAROK_QSTRINGX_H
 #define AMAROK_QSTRINGX_H
 
-#include <qglobal.h>
-#include <QRegExp>
-#include <QString>
 #include <QStringList>
-#include <qmap.h>
+#include <QMap>
 
 namespace Amarok
 {
@@ -32,11 +29,11 @@ class QStringx : public QString
 {
 public:
     QStringx();
-    QStringx( QChar ch );
-    QStringx( const QString &s );
-    QStringx( const QByteArray &ba );
+    explicit QStringx( QChar ch );
+    explicit QStringx( const QString &s );
+    explicit QStringx( const QByteArray &ba );
     QStringx( const QChar *unicode, uint length );
-    QStringx( const char *str );
+    explicit QStringx( const char *str );
     virtual ~QStringx();
 
     // the numbers following % obviously are not taken into account
