@@ -52,13 +52,13 @@ OcsPersonListWidget::OcsPersonListWidget( const QList< KAboutPerson > &persons,
     {
         OcsPersonItem *item = new OcsPersonItem( persons.at( i ), ocsPersons->at( i ).first, status, m_personsArea );
         m_areaLayout->addWidget( item );
-        connect( item, SIGNAL(ocsFetchStarted()), this, SLOT(onOcsFetchStarted()) );
-        connect( item, SIGNAL(ocsFetchResult(int)), this, SLOT(onOcsDataFetched(int)) );
+        connect( item, &OcsPersonItem::ocsFetchStarted, this, &OcsPersonListWidget::onOcsFetchStarted );
+        connect( item, &OcsPersonItem::ocsFetchResult, this, &OcsPersonListWidget::onOcsDataFetched );
     }
 }
 
 void
-OcsPersonListWidget::switchToOcs( const AmarokAttica::Provider &provider )
+OcsPersonListWidget::switchToOcs( Attica::Provider &provider )
 {
     for( int i = 0; i < m_areaLayout->count(); ++i )
     {
@@ -83,6 +83,6 @@ OcsPersonListWidget::onOcsDataFetched( int err )    //SLOT
     if( m_fetchCount == 0 )
     {
         debug()<<m_status<<"FETCH COMPLETE";
-        emit switchedToOcs();
+        Q_EMIT switchedToOcs();
     }
 }
