@@ -19,7 +19,8 @@
 
 #include "OcsPersonItem.h"
 #include "OcsData.h"
-#include "libattica-ocsclient/provider.h"
+#include <Attica/Provider>
+#include <KAboutData>
 
 class OcsPersonListWidget : public QWidget
 {
@@ -29,14 +30,14 @@ public:
     OcsPersonListWidget( const QList< KAboutPerson > &persons,
                          const OcsData::OcsPersonList *ocsPersons,
                          OcsPersonItem::PersonStatus status = OcsPersonItem::Author,
-                         QWidget *parent = 0 );
+                         QWidget *parent = nullptr );
 
-public slots:
-    void switchToOcs( const AmarokAttica::Provider &provider );
+public Q_SLOTS:
+    void switchToOcs( Attica::Provider &provider );
     void onOcsFetchStarted();
     void onOcsDataFetched( int err );
 
-signals:
+Q_SIGNALS:
     void switchedToOcs();
 
 private:
