@@ -38,6 +38,7 @@ namespace Collections
 }
 class CollectionTreeItem;
 class QTimeLine;
+class TrackLoaderJob;
 
 typedef QPair<Collections::Collection*, CollectionTreeItem* > CollectionRoot;
 
@@ -48,25 +49,27 @@ class AMAROK_EXPORT CollectionTreeItemModelBase : public QAbstractItemModel
 {
         Q_OBJECT
 
+    friend class TrackLoaderJob;
+
     public:
         CollectionTreeItemModelBase();
-        virtual ~CollectionTreeItemModelBase();
+        ~CollectionTreeItemModelBase() override;
 
-        virtual Qt::ItemFlags flags(const QModelIndex &index) const;
-        virtual QVariant headerData(int section, Qt::Orientation orientation,
-                            int role = Qt::DisplayRole) const;
-        virtual QModelIndex index(int row, int column,
-                        const QModelIndex &parent = QModelIndex()) const;
-        virtual QModelIndex parent(const QModelIndex &index) const;
-        virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;
-        virtual int columnCount(const QModelIndex &parent = QModelIndex()) const;
-        virtual bool hasChildren ( const QModelIndex & parent = QModelIndex() ) const;
+        Qt::ItemFlags flags(const QModelIndex &index) const override;
+        QVariant headerData(int section, Qt::Orientation orientation,
+                            int role = Qt::DisplayRole) const override;
+        QModelIndex index(int row, int column,
+                        const QModelIndex &parent = QModelIndex()) const override;
+        QModelIndex parent(const QModelIndex &index) const override;
+        int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+        int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+        bool hasChildren ( const QModelIndex & parent = QModelIndex() ) const override;
 
         // Writable..
-        virtual bool setData( const QModelIndex &index, const QVariant &value, int role = Qt::EditRole );
+        bool setData( const QModelIndex &index, const QVariant &value, int role = Qt::EditRole ) override;
 
-        virtual QStringList mimeTypes() const;
-        virtual QMimeData* mimeData( const QModelIndexList &indices ) const;
+        QStringList mimeTypes() const override;
+        QMimeData* mimeData( const QModelIndexList &indices ) const override;
         virtual QMimeData* mimeData( const QList<CollectionTreeItem *> &items ) const;
 
         virtual void listForLevel( int level, Collections::QueryMaker *qm, CollectionTreeItem* parent );
@@ -97,8 +100,8 @@ class AMAROK_EXPORT CollectionTreeItemModelBase : public QAbstractItemModel
         void ensureChildrenLoaded( CollectionTreeItem *item );
 
         /**
-         * Get a pointer to colleciton tree item given its index. It is not safe to
-         * cache this pointer unless QWeakPointer is used.
+         * Get a pointer to collection tree item given its index. It is not safe to
+         * cache this pointer unless QPointer is used.
          */
         CollectionTreeItem *treeItem( const QModelIndex &index ) const;
 
@@ -108,20 +111,20 @@ class AMAROK_EXPORT CollectionTreeItemModelBase : public QAbstractItemModel
          */
         QModelIndex itemIndex( CollectionTreeItem *item ) const;
 
-    signals:
+    Q_SIGNALS:
         void expandIndex( const QModelIndex &index );
         void allQueriesFinished( bool autoExpand );
 
-    public slots:
+    public Q_SLOTS:
         virtual void queryDone();
-        void newResultReady( Meta::TrackList );
-        void newResultReady( Meta::ArtistList );
-        void newResultReady( Meta::AlbumList );
-        void newResultReady( Meta::GenreList );
-        void newResultReady( Meta::ComposerList );
-        void newResultReady( Meta::YearList );
-        void newResultReady( Meta::LabelList );
-        virtual void newResultReady( Meta::DataList data );
+        void newTracksReady( const Meta::TrackList &);
+        void newArtistsReady( const Meta::ArtistList &);
+        void newAlbumsReady( const Meta::AlbumList &);
+        void newGenresReady( const Meta::GenreList &);
+        void newComposersReady( const Meta::ComposerList &);
+        void newYearsReady( const Meta::YearList &);
+        void newLabelsReady( const Meta::LabelList &);
+        virtual void newDataReady( const Meta::DataList &data );
 
         /**
          * Apply the current filter.
@@ -131,6 +134,7 @@ class AMAROK_EXPORT CollectionTreeItemModelBase : public QAbstractItemModel
          * user has actually just typed something and defaults to false.
          */
         void slotFilter( bool autoExpand = false );
+        void slotFilterWithoutAutoExpand() { slotFilter( false ); }
 
         void slotCollapsed( const QModelIndex &index );
         void slotExpanded( const QModelIndex &index );
@@ -140,6 +144,10 @@ class AMAROK_EXPORT CollectionTreeItemModelBase : public QAbstractItemModel
         void handleNormalQueryResult( Collections::QueryMaker *qm, const Meta::DataList &dataList );
 
         Collections::QueryMaker::QueryType mapCategoryToQueryType( int levelType ) const;
+        void tracksLoaded( const Meta::AlbumPtr &album, const QModelIndex &index, const Meta::TrackList &tracks );
+
+        QHash<Meta::Album *, int> m_years;
+        mutable QSet<Meta::AlbumPtr> m_loadingAlbums;
 
     protected:
         /** Adds the query maker to the running queries and connects the slots */
@@ -192,7 +200,7 @@ class AMAROK_EXPORT CollectionTreeItemModelBase : public QAbstractItemModel
         mutable QMultiHash<CollectionTreeItem*, Collections::QueryMaker*> m_runningQueries;
         bool m_autoExpand; // whether to expand tree after queries are done
 
-    protected slots:
+    protected Q_SLOTS:
         void startAnimationTick();
         void loadingAnimationTick();
 };
