@@ -50,14 +50,16 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 
+#include <algorithm>
+
 FileView::FileView( QWidget *parent )
     : Amarok::PrettyTreeView( parent )
-    , m_appendAction( 0 )
-    , m_loadAction( 0 )
-    , m_editAction( 0 )
-    , m_moveToTrashAction( 0 )
-    , m_deleteAction( 0 )
-    , m_pd( 0 )
+    , m_appendAction( nullptr )
+    , m_loadAction( nullptr )
+    , m_editAction( nullptr )
+    , m_moveToTrashAction( nullptr )
+    , m_deleteAction( nullptr )
+    , m_pd( nullptr )
     , m_ongoingDrag( false )
 {
     setFrameStyle( QFrame::NoFrame );
@@ -162,7 +164,7 @@ FileView::mouseReleaseEvent( QMouseEvent *event )
     if( state() == QAbstractItemView::NoState &&
         event->button() == Qt::LeftButton &&
         event->modifiers() == Qt::NoModifier &&
-        style()->styleHint( QStyle::SH_ItemView_ActivateItemOnSingleClick, 0, this ) &&
+        style()->styleHint( QStyle::SH_ItemView_ActivateItemOnSingleClick, nullptr, this ) &&
         ( file.isDir() || file.isNull() ) )
     {
         Q_EMIT navigateToDirectory( index );
@@ -454,7 +456,7 @@ FileView::addIndicesToPlaylist( QModelIndexList indices, Playlist::AddOptions op
         return;
 
     // let tracks & playlists appear in playlist as they are shown in the view:
-    qSort( indices );
+    std::sort( indices.begin(), indices.end() );
 
     QList<QUrl> urls;
     foreach( const QModelIndex &index, indices )
