@@ -44,12 +44,14 @@
 
 #include <KConfigGroup>
 
+#include <algorithm>
+
 using namespace PlaylistBrowserNS;
 
 PlaylistBrowserNS::PlaylistBrowserView::PlaylistBrowserView( QAbstractItemModel *model,
                                                              QWidget *parent )
     : Amarok::PrettyTreeView( parent )
-    , m_pd( 0 )
+    , m_pd( nullptr )
     , m_ongoingDrag( false )
 {
     DEBUG_BLOCK
@@ -114,7 +116,7 @@ void
 PlaylistBrowserNS::PlaylistBrowserView::setModel( QAbstractItemModel *model )
 {
     if( this->model() )
-        disconnect( this->model(), 0, this, 0 );
+        disconnect( this->model(), nullptr, this, nullptr );
     Amarok::PrettyTreeView::setModel( model );
 
     connect( this->model(), SIGNAL(renameIndex(QModelIndex)), SLOT(edit(QModelIndex)) );
@@ -127,7 +129,7 @@ PlaylistBrowserNS::PlaylistBrowserView::mouseReleaseEvent( QMouseEvent *event )
     {
         connect( m_pd, &PopupDropper::fadeHideFinished, m_pd, &QObject::deleteLater );
         m_pd->hide();
-        m_pd = 0;
+        m_pd = nullptr;
     }
 
     QModelIndex index = indexAt( event->pos() );
@@ -234,7 +236,7 @@ PlaylistBrowserNS::PlaylistBrowserView::mouseDoubleClickEvent( QMouseEvent *even
     // mind bug 279513
     bool isExpandable = model()->hasChildren( index );
     bool wouldExpand = !visualRect( index ).contains( event->pos() ) || // clicked outside item, perhaps on expander icon
-                       ( isExpandable && !style()->styleHint( QStyle::SH_ItemView_ActivateItemOnSingleClick, 0, this ) ); // we're in doubleClick
+                       ( isExpandable && !style()->styleHint( QStyle::SH_ItemView_ActivateItemOnSingleClick, nullptr, this ) ); // we're in doubleClick
     if( event->button() == Qt::LeftButton &&
         event->modifiers() == Qt::NoModifier &&
         !wouldExpand )
@@ -322,7 +324,7 @@ PlaylistBrowserNS::PlaylistBrowserView::actionsFor( const QModelIndexList &index
     }
     // all actions taking provider have only sense with one provider
     if( writableProviders.count() == 1 )
-        m_writableActionProvider = writableProviders.toList().first();
+        m_writableActionProvider = writableProviders.values().first();
 
     // process per-provider actions
     foreach( PlaylistProvider *provider, providers )
@@ -388,7 +390,7 @@ PlaylistBrowserNS::PlaylistBrowserView::actionsFor( const QModelIndexList &index
 void
 PlaylistBrowserView::resetActionTargets()
 {
-    m_writableActionProvider = 0;
+    m_writableActionProvider = nullptr;
     m_actionPlaylists.clear();
     m_writableActionPlaylists.clear();
     m_actionTracks.clear();
@@ -484,7 +486,7 @@ PlaylistBrowserView::slotRemoveTracks()
     foreach( Playlists::PlaylistPtr playlist, m_writableActionTracks.uniqueKeys() )
     {
         QList<int> trackIndices = m_writableActionTracks.values( playlist );
-        qSort( trackIndices );
+        std::sort( trackIndices.begin(), trackIndices.end() );
         int removed = 0;
         foreach( int trackIndex, trackIndices )
         {
@@ -568,7 +570,7 @@ PlaylistBrowserView::insertIntoPlaylist( Playlist::AddOptions options )
 
         Meta::TrackList playlistTracks = playlist->tracks();
         QList<int> positions = m_actionTracks.values( playlist );
-        qSort( positions );
+        std::sort( positions.begin(), positions.end() );
         foreach( int position, positions )
         {
             if( position >= 0 && position < playlistTracks.count() )
