@@ -24,16 +24,30 @@
 #include "core/support/Debug.h"
 
 #include <KCMultiDialog>
-#include <kmessagebox.h>
 
 
-PlaybackConfig::PlaybackConfig( QWidget* parent )
+PlaybackConfig::PlaybackConfig( Amarok2ConfigDialog* parent )
     : ConfigDialogBase( parent )
 {
     setupUi( this );
-    kcfg_FadeoutOnExit->setHidden( true );
 
-    connect( findChild<QPushButton*>( "pushButtonPhonon" ), SIGNAL( clicked() ), SLOT( configurePhonon() ) );
+    EngineController *engine = EngineController::instance();
+    Q_ASSERT( engine );
+    if( !engine->supportsFadeout() )
+    {
+        const QString toolTip = i18n( "Current Phonon backend does not support volume fading" );
+        kcfg_FadeoutOnStop->setEnabled( false );
+        kcfg_FadeoutOnStop->setToolTip( toolTip );
+        kcfg_FadeoutOnPause->setEnabled( false );
+        kcfg_FadeoutOnPause->setToolTip( toolTip );
+        fadeoutLengthLabel->setEnabled( false );
+        fadeoutLengthLabel->setToolTip( toolTip );
+        kcfg_FadeoutLength->setEnabled( false );
+        kcfg_FadeoutLength->setToolTip( toolTip );
+    }
+
+    connect( kcfg_FadeoutOnStop, &QCheckBox::toggled, this, &PlaybackConfig::setFadeoutState );
+    connect( kcfg_FadeoutOnPause, &QCheckBox::toggled, this, &PlaybackConfig::setFadeoutState );
 }
 
 PlaybackConfig::~PlaybackConfig()
@@ -66,15 +80,15 @@ PlaybackConfig::updateSettings()
 ///////////////////////////////////////////////////////////////
 
 void
-PlaybackConfig::configurePhonon() //SLOT
+PlaybackConfig::setFadeoutState() //SLOT
 {
-    DEBUG_BLOCK
+    if( !EngineController::instance()->supportsFadeout() )
+        return;
 
-    KCMultiDialog KCM;
+    const bool enabled = kcfg_FadeoutOnPause->isChecked() || kcfg_FadeoutOnStop->isChecked();
 
-    KCM.setWindowTitle( i18n( "Sound System - Amarok" ) );
-    KCM.addModule( "kcm_phonon" );
-    KCM.exec();
+    fadeoutLengthLabel->setEnabled( enabled );
+    kcfg_FadeoutLength->setEnabled( enabled );
 }
 
-#include "PlaybackConfig.moc"
+
