@@ -29,7 +29,7 @@
 #include "core-impl/collections/support/CollectionManager.h"
 
 #include <KIO/Job>
-#include <KLocale>
+#include <KLocalizedString>
 
 #include <QDomDocument>
 
@@ -271,13 +271,13 @@ LabelsEngine::fetchLastFm()
     if( !currentArtist.isEmpty() && !currentTitle.isEmpty() )
     {
         setData( "labels", "message", "fetching");
-        // send the atist and title actually used for searching labels
+        // send the artist and title actually used for searching labels
         setData( "labels", "artist", currentArtist );
         setData( "labels", "title", currentTitle );
         setData( "labels", "album", m_album );
 
         // Query lastfm
-        KUrl lastFmUrl;
+        QUrl lastFmUrl;
         lastFmUrl.setScheme( "http" );
         lastFmUrl.setHost( "ws.audioscrobbler.com" );
         lastFmUrl.setPath( "/2.0/" );
@@ -291,7 +291,7 @@ LabelsEngine::fetchLastFm()
 //         req.setAttribute( QNetworkRequest::ConnectionEncryptedAttribute, QNetworkRequest::AlwaysNetwork );
         The::networkAccessManager()->get( req );
         The::networkAccessManager()->getData( lastFmUrl, this,
-            SLOT(resultLastFm(KUrl,QByteArray,NetworkAccessManagerProxy::Error)) );
+            SLOT(resultLastFm(QUrl,QByteArray,NetworkAccessManagerProxy::Error)) );
     }
     else
     {
@@ -302,7 +302,7 @@ LabelsEngine::fetchLastFm()
     }
 }
 
-void LabelsEngine::resultLastFm( const KUrl &url, QByteArray data, NetworkAccessManagerProxy::Error e )
+void LabelsEngine::resultLastFm( const QUrl &url, QByteArray data, NetworkAccessManagerProxy::Error e )
 {
     DEBUG_BLOCK;
 
@@ -370,5 +370,4 @@ void LabelsEngine::timeout()
 }
 
 
-#include "LabelsEngine.moc"
 
