@@ -50,7 +50,7 @@ IpodCopyTracksJob::IpodCopyTracksJob( const QMap<Meta::TrackPtr,QUrl> &sources,
              this, &IpodCopyTracksJob::slotStartDuplicateTrackSearch );
     connect( this, &IpodCopyTracksJob::startCopyOrTranscodeJob,
              this, &IpodCopyTracksJob::slotStartCopyOrTranscodeJob );
-    connect( this, &IpodCopyTracksJob::displaySorryDialog, this, &IpodCopyTracksJob::slotDisplaySorryDialog );
+    connect( this, &IpodCopyTracksJob::displayErrorDialog, this, &IpodCopyTracksJob::slotDisplayErrorDialog );
 }
 
 void
@@ -117,13 +117,13 @@ IpodCopyTracksJob::run(ThreadWeaver::JobPointer self, ThreadWeaver::Thread *thre
 
         /* determine destination filename; we cannot use ipodTrack because as it has no itdb
          * (and thus mountpoint) set */
-        GError *error = 0;
-        gchar *destFilename = itdb_cp_get_dest_filename( 0, mountPoint, fakeSrcName, &error );
+        GError *error = nullptr;
+        gchar *destFilename = itdb_cp_get_dest_filename( nullptr, mountPoint, fakeSrcName, &error );
         if( error )
         {
             warning() << "Cannot construct iPod track filename:" << error->message;
             g_error_free( error );
-            error = 0;
+            error = nullptr;
         }
         if( !destFilename )
         {
@@ -175,7 +175,7 @@ IpodCopyTracksJob::run(ThreadWeaver::JobPointer self, ThreadWeaver::Thread *thre
         // tell the track it has been copied:
         bool accepted = ipodTrack->finalizeCopying( mountPoint, destFilename );
         g_free( destFilename );
-        destFilename = 0;
+        destFilename = nullptr;
         if( !accepted )
         {
             debug() << "ipodTrack->finalizeCopying( destFilename )  returned false!";
@@ -248,7 +248,7 @@ IpodCopyTracksJob::run(ThreadWeaver::JobPointer self, ThreadWeaver::Thread *thre
     else
     {
         // something more severe failed, notify user using a dialog
-        Q_EMIT displaySorryDialog();
+        Q_EMIT displayErrorDialog();
     }
 }
 
@@ -315,10 +315,16 @@ IpodCopyTracksJob::slotDuplicateTrackSearchQueryDone()
 }
 
 void
-IpodCopyTracksJob::slotStartCopyOrTranscodeJob( const QUrl &sourceUrl, const QUrl &destUrl,
+IpodCopyTracksJob::slotStartCopyOrTranscodeJob( const QUrl &sourceUrlOrig, const QUrl &destUrl,
                                                 bool isJustCopy )
 {
-    KJob *job = 0;
+    QUrl sourceUrl( sourceUrlOrig );
+    // KIO::file_copy in KF5 needs scheme
+    if (sourceUrl.isRelative() && sourceUrl.host().isEmpty()) {
+        sourceUrl.setScheme("file");
+    }
+
+    KJob *job = nullptr;
     if( isJustCopy )
     {
         if( m_goingToRemoveSources && m_coll &&
@@ -340,7 +346,7 @@ IpodCopyTracksJob::slotStartCopyOrTranscodeJob( const QUrl &sourceUrl, const QUr
         debug() << "Transcoding from" << sourceUrl << "to" << destUrl;
         job = new Transcoding::Job( sourceUrl, destUrl, m_transcodingConfig );
     }
-    job->setUiDelegate( 0 ); // be non-interactive
+    job->setUiDelegate( nullptr ); // be non-interactive
     connect( job, &Transcoding::Job::finished, // we must use this instead of result() to prevent deadlock
              this, &IpodCopyTracksJob::slotCopyOrTranscodeJobFinished );
     job->start();  // no-op for KIO job, but matters for transcoding job
@@ -355,7 +361,7 @@ IpodCopyTracksJob::slotCopyOrTranscodeJobFinished( KJob *job )
 }
 
 void
-IpodCopyTracksJob::slotDisplaySorryDialog()
+IpodCopyTracksJob::slotDisplayErrorDialog()
 {
     int sourceSize = m_sources.size();
     int successCount = m_sourceTrackStatus.count( Success );
@@ -389,7 +395,7 @@ IpodCopyTracksJob::slotDisplaySorryDialog()
     int notPlayableCount = m_sourceTrackStatus.count( NotPlayable );
     if( notPlayableCount )
     {
-        QString formats = QStringList( m_notPlayableFormats.toList() ).join( ", " );
+        QString formats = QStringList( m_notPlayableFormats.values() ).join( ", " );
         details += i18np( "One track was not copied because it wouldn't be playable - its "
                           " %2 format is unsupported.<br>",
                           "%1 tracks were not copied because they wouldn't be playable - "
@@ -418,9 +424,9 @@ IpodCopyTracksJob::slotDisplaySorryDialog()
     if( !m_copyErrors.isEmpty() )
     {
         details += i18nc( "%1 is a list of errors that occurred during copying of tracks",
-                          "Error causes: %1<br>", QStringList( m_copyErrors.toList() ).join( "<br>" ) );
+                          "Error causes: %1<br>", QStringList( m_copyErrors.values() ).join( "<br>" ) );
     }
-    KMessageBox::detailedSorry( nullptr, text, details, caption );
+    KMessageBox::detailedError( nullptr, text, details, caption );
 }
 
 void
