@@ -266,7 +266,7 @@ Collections::semanticDateTimeParser( const QString &text, bool *absolute )
         *absolute = false;
 
     // parse date using local settings
-    QDateTime result = QLocale().toDateTime( text, QLocale::ShortFormat );
+    QDateTime result = QLocale().toDate( text, QLocale::ShortFormat ).startOfDay();
 
     // parse date using a backup standard independent from local settings
     QRegExp shortDateReg("(\\d{1,2})[-.](\\d{1,2})");
@@ -290,15 +290,15 @@ Collections::semanticDateTimeParser( const QString &text, bool *absolute )
         if( absolute )
             *absolute = true;
     }
-    else if( text.contains(shortDateReg) )
+    else if( text.contains(longDateReg) )
     {
-        result = QDateTime( QDate( QDate::currentDate().year(), shortDateReg.cap(2).toInt(), shortDateReg.cap(1).toInt() ) );
+        result = QDate( longDateReg.cap(3).toInt(), longDateReg.cap(2).toInt(), longDateReg.cap(1).toInt() ).startOfDay();
         if( absolute )
             *absolute = true;
     }
-    else if( text.contains(longDateReg) )
+    else if( text.contains(shortDateReg) )
     {
-        result = QDateTime( QDate( longDateReg.cap(3).toInt(), longDateReg.cap(2).toInt(), longDateReg.cap(1).toInt() ) );
+        result = QDate( QDate::currentDate().year(), shortDateReg.cap(2).toInt(), shortDateReg.cap(1).toInt() ).startOfDay();
         if( absolute )
             *absolute = true;
     }
