@@ -22,7 +22,7 @@
 
 using namespace Playlists;
 
-M3UPlaylist::M3UPlaylist( const KUrl &url, PlaylistProvider *provider )
+M3UPlaylist::M3UPlaylist( const QUrl &url, PlaylistProvider *provider )
     : PlaylistFile( url, provider )
 {
 }
@@ -32,7 +32,6 @@ M3UPlaylist::loadM3u( QTextStream &stream )
 {
     if( m_tracksLoaded )
         return true;
-    const QString directory = m_url.directory();
     m_tracksLoaded = true;
 
     int length = -1;
@@ -40,24 +39,24 @@ M3UPlaylist::loadM3u( QTextStream &stream )
     do
     {
         QString line = stream.readLine();
-        if( line.startsWith( "#EXTINF" ) )
+        if( line.startsWith( QLatin1String("#EXTINF") ) )
         {
-            const QString extinf = line.section( ':', 1 );
+            const QString extinf = line.section( QLatin1Char(':'), 1 );
             bool ok;
-            length = extinf.section( ',', 0, 0 ).toInt( &ok );
+            length = extinf.section( QLatin1Char(','), 0, 0 ).toInt( &ok );
             if( !ok )
                 length = -1;
-            extinfTitle = extinf.section( ',', 1 );
+            extinfTitle = extinf.section( QLatin1Char(','), 1 );
         }
         else if( !line.startsWith( '#' ) && !line.isEmpty() )
         {
-            line = line.replace( "\\", "/" );
+            line = line.replace( QLatin1String("\\"), QLatin1String("/") );
 
-            KUrl url = getAbsolutePath( KUrl( line ) );
+            QUrl url = getAbsolutePath( QUrl( line ) );
 
             MetaProxy::TrackPtr proxyTrack( new MetaProxy::Track( url ) );
-            QString artist = extinfTitle.section( " - ", 0, 0 );
-            QString title = extinfTitle.section( " - ", 1, 1 );
+            QString artist = extinfTitle.section( QStringLiteral(" - "), 0, 0 );
+            QString title = extinfTitle.section( QStringLiteral(" - "), 1, 1 );
             //if title and artist are saved such as in M3UPlaylist::save()
             if( !title.isEmpty() && !artist.isEmpty() )
             {
@@ -84,7 +83,7 @@ M3UPlaylist::savePlaylist( QFile &file )
     QTextStream stream( &file );
 
     stream << "#EXTM3U\n";
-    KUrl::List urls;
+    QList<QUrl> urls;
     QStringList titles;
     QList<int> lengths;
 
@@ -93,7 +92,7 @@ M3UPlaylist::savePlaylist( QFile &file )
         if( !track ) // see BUG: 303056
             continue;
 
-        const KUrl &url = track->playableUrl();
+        const QUrl &url = track->playableUrl();
         int length = track->length() / 1000;
         const QString &title = track->name();
         const QString &artist = track->artist()->name();
@@ -107,7 +106,7 @@ M3UPlaylist::savePlaylist( QFile &file )
             stream << '\n';
         }
 
-        if( url.protocol() == "file" )
+        if( url.scheme() == QLatin1String("file") )
             stream << trackLocation( track );
         else
             stream << url.url();
