@@ -28,6 +28,8 @@
 #include <QDate>
 #include <QSet>
 
+#include <algorithm>
+
 using namespace Podcasts;
 
 #define ITUNES_NS  "http://www.itunes.com/dtds/podcast-1.0.dtd"
@@ -93,7 +95,7 @@ PodcastReader::StaticData::StaticData()
 
         , docAction(
             docMap,
-            0,
+            nullptr,
             &PodcastReader::endDocument )
         , xmlAction(
             xmlMap,
@@ -104,7 +106,7 @@ PodcastReader::StaticData::StaticData()
         , noContentAction(
             noContentMap,
             &PodcastReader::beginNoElement,
-            0,
+            nullptr,
             &PodcastReader::readNoCharacters )
 
         , rdfAction(
@@ -236,12 +238,12 @@ PodcastReader::StaticData::StaticData()
         , atomFeedLinkAction(
             noContentMap,
             &PodcastReader::beginAtomFeedLink,
-            0,
+            nullptr,
             &PodcastReader::readNoCharacters )
         , atomEntryLinkAction(
             noContentMap,
             &PodcastReader::beginAtomEntryLink,
-            0,
+            nullptr,
             &PodcastReader::readNoCharacters )
         , atomIdAction(
             textMap,
@@ -510,7 +512,7 @@ PodcastReader::downloadResult( KJob * job )
         }
         errorMessage = errorMessage.append( job->errorString() );
 
-        Q_EMIT statusBarSorryMessage( errorMessage );
+        Q_EMIT statusBarErrorMessage( errorMessage );
     }
     else if( job->error() )
     {
@@ -524,7 +526,7 @@ PodcastReader::downloadResult( KJob * job )
         }
         errorMessage = errorMessage.append( job->errorString() );
 
-        Q_EMIT statusBarSorryMessage( errorMessage );
+        Q_EMIT statusBarErrorMessage( errorMessage );
     }
 
     m_transferJob = nullptr;
@@ -1190,7 +1192,7 @@ PodcastReader::endItem()
     }
 
     m_current = m_channel.data();
-    m_item = 0;
+    m_item = nullptr;
 }
 
 void
@@ -1281,7 +1283,7 @@ PodcastReader::endKeywords()
             keywords.append( kwd );
     }
 
-    qSort( keywords );
+    std::sort( keywords.begin(), keywords.end() );
     m_current->setKeywords( keywords );
 
 }
