@@ -16,14 +16,15 @@
  
 #include "DBusQueryHelper.h"
 
-#include "core/support/Debug.h"
 #include "core/collections/QueryMaker.h"
+#include "core/meta/Meta.h"
 #include "core/meta/support/MetaUtility.h"
+#include "core/support/Debug.h"
 
 #include <QTimer>
 
 Q_DECLARE_METATYPE( VariantMapList )
- 
+
 DBusQueryHelper::DBusQueryHelper( QObject *parent, Collections::QueryMaker *qm, const QDBusConnection &conn, const QDBusMessage &msg, bool mprisCompatible )
     : QObject( parent )
     , m_connection( conn )
@@ -33,18 +34,17 @@ DBusQueryHelper::DBusQueryHelper( QObject *parent, Collections::QueryMaker *qm,
 {
     qm->setAutoDelete( true );
     qm->setQueryType( Collections::QueryMaker::Track );
-    connect( qm, SIGNAL( newResultReady( QString, Meta::TrackList ) ), this, SLOT( slotResultReady( QString, Meta::TrackList ) ), Qt::QueuedConnection );
-    connect( qm, SIGNAL( queryDone() ), this, SLOT( slotQueryDone() ), Qt::QueuedConnection );
+    connect( qm, &Collections::QueryMaker::newTracksReady, this, &DBusQueryHelper::slotResultReady, Qt::QueuedConnection );
+    connect( qm, &Collections::QueryMaker::queryDone, this, &DBusQueryHelper::slotQueryDone, Qt::QueuedConnection );
     qm->run();
 
     //abort query after 15 seconds in case the query does not return
-    QTimer::singleShot( 15000, this, SLOT( abortQuery() ) );
+    QTimer::singleShot( 15000, this, &DBusQueryHelper::abortQuery );
 }
 
 void
-DBusQueryHelper::slotResultReady( const QString &collectionId, const Meta::TrackList &tracks )
+DBusQueryHelper::slotResultReady( const Meta::TrackList &tracks )
 {
-    Q_UNUSED( collectionId );
     foreach( const Meta::TrackPtr &track, tracks )
     {
         if( m_mprisCompatibleResult )
@@ -74,7 +74,7 @@ DBusQueryHelper::abortQuery()
     deleteLater();
     m_timeout = true;
 
-    QDBusMessage error = m_message.createError( QDBusError::InternalError, "Internal timeout" );
+    QDBusMessage error = m_message.createErrorReply( QDBusError::InternalError, QStringLiteral("Internal timeout") );
     bool success = m_connection.send( error );
     if( !success )
         debug() << "sending async error failed";
