@@ -47,6 +47,7 @@
 #include "playlist/PlaylistRestorer.h"
 #include "playlistmanager/PlaylistManager.h"
 
+#include <QRandomGenerator>
 #include <QStandardPaths>
 #include <typeinfo>
 
@@ -73,7 +74,7 @@ Playlist::Actions::Actions()
         : QObject()
         , m_nextTrackCandidate( 0 )
         , m_stopAfterPlayingTrackId( 0 )
-        , m_navigator( 0 )
+        , m_navigator( nullptr )
         , m_waitingForNextTrack( false )
 {
     EngineController *engine = The::engineController();
@@ -251,7 +252,7 @@ Playlist::Actions::enableDynamicMode( bool enable )
     AmarokConfig::self()->save();
 
     Playlist::Dock *dock = The::mainWindow()->playlistDock();
-    Playlist::SortWidget *sorting = dock ? dock->sortWidget() : 0;
+    Playlist::SortWidget *sorting = dock ? dock->sortWidget() : nullptr;
     if( sorting )
         sorting->trimToLevel();
 
@@ -291,7 +292,7 @@ Playlist::Actions::playlistModeChanged()
         return;
     }
 
-    m_navigator = 0;
+    m_navigator = nullptr;
 
     switch( AmarokConfig::trackProgression() )
     {
@@ -362,7 +363,7 @@ Playlist::Actions::shuffle()
         for( int row = 0; row < rowCount; ++row )
         {
             fromRows.append( row );
-            shuffleToRows.insert( qrand(), row );
+            shuffleToRows.insert( QRandomGenerator::global()->generate(), row );
         }
         toRows = shuffleToRows.values();
     }
@@ -400,6 +401,15 @@ Playlist::Actions::queueMoveDown( quint64 id )
     return ret;
 }
 
+bool
+Playlist::Actions::queueMoveTo( quint64 id, const int pos )
+{
+    const bool ret = m_navigator->queueMoveTo( id, pos );
+    if ( ret )
+        Playlist::ModelStack::instance()->bottom()->emitQueueChanged();
+    return ret;
+}
+
 void
 Playlist::Actions::dequeue( quint64 id )
 {
