@@ -54,6 +54,8 @@
 #include <QStringList>
 #include <QUrl>
 
+#include <algorithm>
+
 
 #define TOOLTIP_STATIC_LINEBREAK 50
 
@@ -659,7 +661,7 @@ Playlist::Model::dropMimeData( const QMimeData* data, Qt::DropAction action, int
         {
 
             Meta::TrackList tracks = trackListDrag->tracks();
-            qStableSort( tracks.begin(), tracks.end(), Meta::Track::lessThan );
+            std::stable_sort( tracks.begin(), tracks.end(), Meta::Track::lessThan );
 
             The::playlistController()->insertTracks( beginRow, tracks );
         }
@@ -817,7 +819,7 @@ Playlist::Model::rowForId( const quint64 id ) const
 Meta::TrackPtr
 Playlist::Model::trackForId( const quint64 id ) const
 {
-    Item* item = m_itemIds.value( id, 0 );
+    Item* item = m_itemIds.value( id, nullptr );
     if ( item )
         return item->track();
     else
@@ -845,7 +847,7 @@ Playlist::Model::activeId() const
 Playlist::Item::State
 Playlist::Model::stateOfId( quint64 id ) const
 {
-    Item* item = m_itemIds.value( id, 0 );
+    Item* item = m_itemIds.value( id, nullptr );
     if ( item )
         return item->state();
     else
@@ -1030,7 +1032,7 @@ Playlist::Model::removeTracksCommand( const RemoveCmdList &passedCmds )
 
     // sort tracks to remove by their row
     RemoveCmdList cmds( passedCmds );
-    qSort( cmds.begin(), cmds.end(), removeCmdLessThanByRow );
+    std::sort( cmds.begin(), cmds.end(), removeCmdLessThanByRow );
 
     // update the active row
     if( m_activeRow >= 0 )
