@@ -51,18 +51,18 @@ class PrettyListView : public QListView, public ViewCommon
     Q_OBJECT
 
 public:
-    PrettyListView( QWidget* parent = 0 );
-    ~PrettyListView();
+    explicit PrettyListView( QWidget* parent = nullptr );
+    ~PrettyListView() override;
 
 protected:
-    int verticalOffset() const;
+    int verticalOffset() const override;
 
-signals:
+Q_SIGNALS:
     void found();
     void notFound();
 
     // these slots are used by the ContextMenu
-public slots:
+public Q_SLOTS:
     void editTrackInformation();
     void playFirstSelected();
     void dequeueSelection();
@@ -88,28 +88,29 @@ public slots:
     void findPrevious( const QString & searchTerm, int fields  );
     void clearSearchTerm();
     void showOnlyMatches( bool onlyMatches );
+    void findInSource();
 
 protected:
-    void showEvent( QShowEvent* );
-    void contextMenuEvent( QContextMenuEvent* );
-    void dragEnterEvent( QDragEnterEvent *event );
-    void dragLeaveEvent( QDragLeaveEvent* );
-    void dragMoveEvent( QDragMoveEvent* );
-    void dropEvent( QDropEvent* );
-    void keyPressEvent( QKeyEvent* );
-    void mousePressEvent( QMouseEvent* );
-    void mouseReleaseEvent( QMouseEvent* );
+    void showEvent( QShowEvent* ) override;
+    void contextMenuEvent( QContextMenuEvent* ) override;
+    void dragEnterEvent( QDragEnterEvent *event ) override;
+    void dragLeaveEvent( QDragLeaveEvent* ) override;
+    void dragMoveEvent( QDragMoveEvent* ) override;
+    void dropEvent( QDropEvent* ) override;
+    void keyPressEvent( QKeyEvent* ) override;
+    void mousePressEvent( QMouseEvent* ) override;
+    void mouseReleaseEvent( QMouseEvent* ) override;
 
     /** Draws a "drop here" text if empty */
-    void paintEvent( QPaintEvent* );
+    void paintEvent( QPaintEvent* ) override;
 
-    void startDrag( Qt::DropActions supportedActions );
-    bool edit( const QModelIndex &index, EditTrigger trigger, QEvent *event );
+    void startDrag( Qt::DropActions supportedActions ) override;
+    bool edit( const QModelIndex &index, EditTrigger trigger, QEvent *event ) override;
 
-protected slots:
+protected Q_SLOTS:
     void newPalette( const QPalette & palette );
 
-private slots:
+private Q_SLOTS:
     void slotPlaylistActiveTrackChanged();
     void bottomModelRowsInserted( const QModelIndex& parent, int start, int end );
     void bottomModelRowsInsertedScroll();
@@ -121,7 +122,6 @@ private slots:
     void fixInvisible(); // Workaround for BUG 184714; see implementation for more comments.
     void redrawActive();
     void playlistLayoutChanged();
-    void findInSource();
 
 private:
     bool mouseEventInHeader( const QMouseEvent* ) const;
