@@ -216,10 +216,7 @@ AmarokCollectionViewScript::setLevel( int level, int type )
         m_collectionWidget->currentView()->setLevel( level, CategoryId::CatMenuId( type ) );
         return;
     }
-    /* TODO - Use commented code once QT versions >= 5.12
     m_engine->throwError( QJSValue::TypeError, QStringLiteral("Invalid category!") );
-    */
-    m_engine->evaluate("throw new TypeError('Invalid category!')");
 }
 
 void
@@ -230,10 +227,7 @@ AmarokCollectionViewScript::setLevels( const QList<int> &levels )
     {
         if( !m_categoryEnum.valueToKey( level ) )
         {
-            /* TODO - Use commented code once QT versions >= 5.12
             m_engine->throwError( QJSValue::TypeError, QStringLiteral("Invalid category!") );
-            */
-            m_engine->evaluate("throw new TypeError('Invalid category!')");
             return;
         }
         catLevels << CategoryId::CatMenuId( level );
@@ -372,13 +366,13 @@ CollectionViewItem::slotDataChanged( const QModelIndex &topLeft, const QModelInd
     if( static_cast<CollectionTreeItem*>( topLeft.internalPointer() ) != m_item )
         return;
     Q_EMIT loaded( m_item );
-    Q_ASSERT( disconnect( qobject_cast<QAbstractItemModel*>(sender()), &QAbstractItemModel::dataChanged, this, 0 ) );
+    Q_ASSERT( disconnect( qobject_cast<QAbstractItemModel*>(sender()), &QAbstractItemModel::dataChanged, this, nullptr ) );
 }
 
 Collections::QueryMaker*
 CollectionViewItem::queryMaker()
 {
-    Collections::QueryMaker *qm = 0;
+    Collections::QueryMaker *qm = nullptr;
     if( The::mainWindow()->collectionBrowser()->viewMode() == CollectionWidget::NormalCollections )
         qm = m_item->queryMaker();
     else
@@ -402,7 +396,7 @@ CollectionTreeItemModelBase*
 CollectionViewItem::getModel()
 {
     QSortFilterProxyModel *proxyModel = dynamic_cast<QSortFilterProxyModel*>( The::mainWindow()->collectionBrowser()->currentView()->model() );
-    return dynamic_cast<CollectionTreeItemModelBase*>( proxyModel ? proxyModel->sourceModel() : 0 );
+    return dynamic_cast<CollectionTreeItemModelBase*>( proxyModel ? proxyModel->sourceModel() : nullptr );
 }
 
 ///////////////////////////////////////////////////////////
@@ -432,5 +426,6 @@ Selection::Selection( const QModelIndexList &indices )
 Collections::QueryMaker*
 Selection::queryMaker()
 {
-    return The::mainWindow()->collectionBrowser()->currentView()->createMetaQueryFromItems( selectedItems().toSet(), true );
+    QList<CollectionTreeItem*> items=selectedItems();
+    return The::mainWindow()->collectionBrowser()->currentView()->createMetaQueryFromItems( QSet<CollectionTreeItem*>(items.begin(), items.end()), true );
 }
