@@ -36,21 +36,21 @@ class ScrobblerAdapter : public QObject, public StatSyncing::ScrobblingService
 
     public:
         ScrobblerAdapter( const QString &clientId, const LastFmServiceConfigPtr &config );
-        virtual ~ScrobblerAdapter();
+        ~ScrobblerAdapter() override;
 
     public:
         // ScrobblingService methods:
-        QString prettyName() const;
+        QString prettyName() const override;
         ScrobbleError scrobble( const Meta::TrackPtr &track, double playedFraction = 1.0,
-                                const QDateTime &time = QDateTime() );
-        void updateNowPlaying( const Meta::TrackPtr &track );
+                                const QDateTime &time = QDateTime() ) override;
+        void updateNowPlaying( const Meta::TrackPtr &track ) override;
 
-    public slots:
+    public Q_SLOTS:
         // own methods
         void loveTrack( const Meta::TrackPtr &track );
         void banTrack( const Meta::TrackPtr &track );
 
-    private slots:
+    private Q_SLOTS:
         void slotScrobblesSubmitted( const QList<lastfm::Track> &tracks );
         void slotNowPlayingError( int code, const QString &message );
 
