@@ -16,12 +16,12 @@
 
 #include "MagnatuneRedownloadDialog.h"
 
-#include "Debug.h"
+#include "core/support/Debug.h"
 
 #include <QHeaderView>
 
-MagnatuneRedownloadDialog::MagnatuneRedownloadDialog(QWidget* parent, const char* name, bool modal, Qt::WFlags fl)
-: QDialog(parent, fl)
+MagnatuneRedownloadDialog::MagnatuneRedownloadDialog(QWidget* parent, const char* name, bool modal, Qt::WindowFlags fl)
+    : QDialog(parent, fl)
 {
     setObjectName( name );
     setModal( modal );
@@ -30,7 +30,7 @@ MagnatuneRedownloadDialog::MagnatuneRedownloadDialog(QWidget* parent, const char
 
     redownloadListView->header()->setStretchLastSection( true );
     redownloadListView->setRootIsDecorated( false );
-    connect( redownloadListView, SIGNAL(itemSelectionChanged()), SLOT(selectionChanged()) );
+    connect( redownloadListView, &QTreeWidget::itemSelectionChanged, this, &MagnatuneRedownloadDialog::selectionChanged );
 }
 
 MagnatuneRedownloadDialog::~MagnatuneRedownloadDialog()
@@ -43,7 +43,7 @@ void MagnatuneRedownloadDialog::setRedownloadItems( const QStringList &items )
      QStringListIterator it(items);
      while ( it.hasNext() ) {
 
-           QString currentItem = it.next();
+           const QString currentItem = it.next();
            debug() << "Adding item to redownload dialog: " << currentItem;
            redownloadListView->addTopLevelItem( new QTreeWidgetItem( QStringList(currentItem) ) );
      }
@@ -52,7 +52,7 @@ void MagnatuneRedownloadDialog::setRedownloadItems( const QStringList &items )
 
 }
 
-void MagnatuneRedownloadDialog::setRedownloadItems( QList<MagnatuneDownloadInfo> previousPurchases )
+void MagnatuneRedownloadDialog::setRedownloadItems( const QList<MagnatuneDownloadInfo> &previousPurchases )
 {
     m_infoMap.clear();
     
@@ -67,16 +67,15 @@ void MagnatuneRedownloadDialog::setRedownloadItems( QList<MagnatuneDownloadInfo>
     
 }
 
-void MagnatuneRedownloadDialog::redownload( )
+void MagnatuneRedownloadDialog::slotRedownload( )
 {
-
     QTreeWidgetItem * current = redownloadListView->currentItem();
     if ( m_infoMap.keys().contains( current ) )
     {
-        emit( redownload( m_infoMap.value( current ) ) );
+        Q_EMIT( redownload( m_infoMap.value( current ) ) );
     }
     
-    //emit ( redownload( redownloadListView->currentItem()->text( 0 ) ) );
+    //Q_EMIT ( redownload( redownloadListView->currentItem()->text( 0 ) ) );
 
     hide();
 }
@@ -84,12 +83,12 @@ void MagnatuneRedownloadDialog::redownload( )
 void MagnatuneRedownloadDialog::reject( )
 {
     hide();
-    emit(cancelled());
+    Q_EMIT(cancelled());
 }
 
 void MagnatuneRedownloadDialog::selectionChanged( )
 {
-    if (redownloadListView->currentItem() != 0) {
+    if (redownloadListView->currentItem()) {
         redownloadButton->setEnabled ( true );
     } else { 
         redownloadButton->setEnabled ( false );
@@ -99,5 +98,4 @@ void MagnatuneRedownloadDialog::selectionChanged( )
 /*$SPECIALIZATION$*/
 
 
-#include "MagnatuneRedownloadDialog.moc"
 
