@@ -31,9 +31,9 @@
 MagnatuneRedownloadHandler::MagnatuneRedownloadHandler(QWidget * parent)
 {
     m_parent = parent;
-    m_redownloadDialog = 0;
-    m_downloadDialog = 0;
-    m_albumDownloader = 0;
+    m_redownloadDialog = nullptr;
+    m_downloadDialog = nullptr;
+    m_albumDownloader = nullptr;
 }
 
 
@@ -170,7 +170,7 @@ void MagnatuneRedownloadHandler::redownloadApiResult( KJob* job )
     KIO::StoredTransferJob* const storedJob = static_cast<KIO::StoredTransferJob*>( job );
     QString resultXml = QString( storedJob->data() );
 
-    debug() << endl << endl << "result: " << resultXml;
+    debug() << Qt::endl << Qt::endl << "result: " << resultXml;
 
 
     QList<MagnatuneDownloadInfo> previousPurchasesInfoList;
@@ -188,7 +188,7 @@ void MagnatuneRedownloadHandler::redownloadApiResult( KJob* job )
     }
 
 
-    if (m_redownloadDialog == 0)
+    if (m_redownloadDialog == nullptr)
     {
         m_redownloadDialog = new MagnatuneRedownloadDialog( m_parent );
         connect( m_redownloadDialog, &MagnatuneRedownloadDialog::redownload, this, &MagnatuneRedownloadHandler::redownload );
