@@ -26,12 +26,12 @@
 #include "services/scriptable/ScriptableServiceInfoParser.h"
 #include "widgets/SearchWidget.h"
 
-#include <KStandardDirs>
+#include <QStandardPaths>
 
 using namespace Meta;
 
 ScriptableService::ScriptableService( const QString & name )
-    : ServiceBase( name, 0 )
+    : ServiceBase( name, nullptr )
     , m_polished( false )
     , m_name( name )
     , m_trackIdCounter( 0 )
@@ -41,9 +41,8 @@ ScriptableService::ScriptableService( const QString & name )
 {
     DEBUG_BLOCK
     debug() << "creating ScriptableService " << name;
-    m_collection = 0;
+    m_collection = nullptr;
     m_bottomPanel->hide();
-
 }
 
 ScriptableService::~ScriptableService()
@@ -101,7 +100,7 @@ int ScriptableService::insertItem( int level, int parentId, const QString & name
             if( !callbackData.isEmpty() || playableUrl.isEmpty() )
                 return -1;
 
-            KSharedPtr<ScriptableServiceTrack> track( new ScriptableServiceTrack( name ) );
+            AmarokSharedPointer<ScriptableServiceTrack> track( new ScriptableServiceTrack( name ) );
             track->setAlbumId( parentId );
             track->setUidUrl( playableUrl );
             track->setServiceName( m_name );
@@ -110,12 +109,12 @@ int ScriptableService::insertItem( int level, int parentId, const QString & name
             if ( !m_customEmblem.isNull() )
                 track->setServiceEmblem( m_customEmblem );
             else
-                track->setServiceEmblem( QPixmap( KStandardDirs::locate( "data", "amarok/images/emblem-scripted.png" ) ) );
+                track->setServiceEmblem( QPixmap( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/emblem-scripted.png") ) ) );
 
             if ( !m_customScalableEmblem.isEmpty() )
                 track->setServiceScalableEmblem( m_customScalableEmblem );
             else
-                track->setServiceEmblem( KStandardDirs::locate( "data", "amarok/images/emblem-scripted-scalable.svgz" ) );
+                track->setServiceEmblem( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/emblem-scripted-scalable.svgz") ) );
 
             if ( !albumOverride.isEmpty() )
                 track->setAlbumName( albumOverride );
@@ -152,12 +151,12 @@ int ScriptableService::insertItem( int level, int parentId, const QString & name
             if ( !m_customEmblem.isNull() )
                 album->setServiceEmblem( m_customEmblem );
             else
-                album->setServiceEmblem( QPixmap( KStandardDirs::locate( "data", "amarok/images/emblem-scripted.png" ) ) );
+                album->setServiceEmblem( QPixmap( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/emblem-scripted.png") ) ) );
 
             if ( !m_customScalableEmblem.isEmpty() )
                 album->setServiceScalableEmblem( m_customScalableEmblem );
             else
-                album->setServiceEmblem( KStandardDirs::locate( "data", "amarok/images/emblem-scripted-scalable.svgz" ) );
+                album->setServiceEmblem( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/emblem-scripted-scalable.svgz") ) );
             
             return addAlbum( album );
             
@@ -178,12 +177,12 @@ int ScriptableService::insertItem( int level, int parentId, const QString & name
             if ( !m_customEmblem.isNull() )
                 artist->setServiceEmblem( m_customEmblem );
             else
-                artist->setServiceEmblem( QPixmap( KStandardDirs::locate( "data", "amarok/images/emblem-scripted.png" ) ) );
+                artist->setServiceEmblem( QPixmap( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/emblem-scripted.png") ) ) );
 
             if ( !m_customScalableEmblem.isEmpty() )
                 artist->setServiceScalableEmblem( m_customScalableEmblem );
             else
-                artist->setServiceEmblem( KStandardDirs::locate( "data", "amarok/images/emblem-scripted-scalable.svgz" ) );
+                artist->setServiceEmblem( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/emblem-scripted-scalable.svgz") ) );
 
             
             return addArtist( artist );
@@ -205,12 +204,12 @@ int ScriptableService::insertItem( int level, int parentId, const QString & name
             if ( !m_customEmblem.isNull() )
                 genre->setServiceEmblem( m_customEmblem );
             else
-                genre->setServiceEmblem( QPixmap( KStandardDirs::locate( "data", "amarok/images/emblem-scripted.png" ) ) );
+                genre->setServiceEmblem( QPixmap( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/emblem-scripted.png") ) ) );
 
             if ( !m_customScalableEmblem.isEmpty() )
                 genre->setServiceScalableEmblem( m_customScalableEmblem );
             else
-                genre->setServiceEmblem( KStandardDirs::locate( "data", "amarok/images/emblem-scripted-scalable.svgz" ) );
+                genre->setServiceEmblem( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/emblem-scripted-scalable.svgz") ) );
 
             
             return addGenre( genre );
@@ -414,6 +413,5 @@ void ScriptableService::setCurrentInfo( const QString & info )
 
 
 
-#include "ScriptableService.moc"
 
 
