@@ -21,6 +21,8 @@
 #include "importers/amarok/AmarokManager.h"
 #include "importers/amarok/AmarokProvider.h"
 
+#include <KLocalizedString>
+
 #include <QProcess>
 #include <QTest>
 
@@ -37,16 +39,16 @@ TestAmarokImporter::getProvider()
     cfg.insert( "name", "Amarok2Test" );
     cfg.insert( "embedded", true );
     cfg.insert( "dbPath", QCoreApplication::applicationDirPath() +
-                          "/importers_files/amarok2_mysqle" );
+                          "/../tests/importers_files/amarok2_mysqle" );
 
-    return ProviderPtr( new AmarokProvider( cfg, 0 ) );
+    return ProviderPtr( new AmarokProvider( cfg, nullptr ) );
 }
 
 ProviderPtr
 TestAmarokImporter::getWritableProvider()
 {
     QDir base( QCoreApplication::applicationDirPath() );
-    QDir files( base.filePath( "importers_files" ) );
+    QDir files( base.filePath( "../tests/importers_files" ) );
     QDir tmp( base.filePath( "importers_tmp" ) );
 
     foreach( const QString &subdir,
@@ -69,7 +71,7 @@ TestAmarokImporter::getWritableProvider()
     cfg.insert( "embedded", true );
     cfg.insert( "dbPath", tmp.filePath( "amarok2_mysqle" ) );
 
-    return ProviderPtr( new AmarokProvider( cfg, 0 ) );
+    return ProviderPtr( new AmarokProvider( cfg, nullptr ) );
 }
 
 qint64
@@ -88,6 +90,7 @@ TestAmarokImporter::initTestCase()
 void
 TestAmarokImporter::init()
 {
+    KLocalizedString::setApplicationDomain("amarok-test");
     m_cfg = AmarokConfigWidget( QVariantMap() ).config();
     m_cfg.insert( "embedded", true );
 }
@@ -179,7 +182,7 @@ TestAmarokImporter::providerShouldIgnoreConfigsDbDriver()
     m_cfg.insert( "dbPath", QCoreApplication::applicationDirPath() +
                             "/importers_files/amarok2_mysqle" );
 
-    AmarokProvider provider( m_cfg, 0 );
+    AmarokProvider provider( m_cfg, nullptr );
 
     // The database isn't accessible by QPSQL driver, but it still should work
     QVERIFY( !provider.artists().empty() );
@@ -190,7 +193,7 @@ TestAmarokImporter::providerShouldHandleNonexistentDbDir()
 {
     m_cfg.insert( "dbPath", "/Im/sure/this/wont/exist" );
 
-    AmarokProvider provider( m_cfg, 0 );
+    AmarokProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
@@ -199,7 +202,7 @@ TestAmarokImporter::providerShouldHandleInvalidDbDir()
 {
     m_cfg.insert( "dbPath", QApplication::applicationDirPath() );
 
-    AmarokProvider provider( m_cfg, 0 );
+    AmarokProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
@@ -208,7 +211,7 @@ TestAmarokImporter::providerShouldHandleExternalConnectionError()
 {
     m_cfg.insert( "dbHost", "I hope this isn't a valid hostname" );
 
-    AmarokProvider provider( m_cfg, 0 );
+    AmarokProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
@@ -219,7 +222,7 @@ TestAmarokImporter::providerShouldHandleErroneousConfigValues()
     m_cfg.insert( "dbName", QColor( Qt::red ) );
     m_cfg.insert( "dbPort", "nonsensePort" );
 
-    AmarokProvider provider( m_cfg, 0 );
+    AmarokProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
