@@ -586,7 +586,7 @@ trackForName( ProviderPtr &provider, const QString &name, const QString &artist
         if( track->name() == name )
             return track;
 
-    return TrackPtr( 0 );
+    return TrackPtr( nullptr );
 }
 
 static Meta::FieldHash
@@ -603,7 +603,7 @@ saveData( const TrackPtr &track )
     data.insert( Meta::valLastPlayed, track->lastPlayed() );
     data.insert( Meta::valRating, track->rating() );
     data.insert( Meta::valPlaycount, track->playCount() );
-    data.insert( Meta::valLabel, QStringList( track->labels().toList() ) );
+    data.insert( Meta::valLabel, QStringList( track->labels().values() ) );
     return data;
 }
 
@@ -698,7 +698,7 @@ TestImporterBase::commitAfterSettingAllStatisticsShouldSaveThem()
     if( provider->writableTrackStatsData() & Meta::valLabel )
     {
         QFETCH( QStringList, newLabels );
-        track->setLabels( newLabels.toSet() );
+        track->setLabels( QSet<QString> ( newLabels.begin(), newLabels.end() ) );
     }
 
     track->commit();
@@ -732,7 +732,7 @@ TestImporterBase::commitAfterSettingAllStatisticsShouldSaveThem()
     if( provider->writableTrackStatsData() & Meta::valLabel )
     {
         QFETCH( QStringList, newLabels );
-        QCOMPARE( track->labels(), newLabels.toSet() );
+        QCOMPARE( track->labels(), QSet<QString> ( newLabels.begin(), newLabels.end() ) );
     }
 
     verifyEqualExcept( data, track, Meta::valFirstPlayed | Meta::valLastPlayed |
@@ -957,12 +957,12 @@ TestImporterBase::commitAfterSettingLabelsShouldSaveThem()
     QVERIFY( track );
 
     const Meta::FieldHash data = saveData( track );
-    track->setLabels( newLabels.toSet() );
+    track->setLabels( QSet<QString> ( newLabels.begin(), newLabels.end() ) );
     track->commit();
     provider->commitTracks();
 
     track = trackForName( provider, title, "testStatistics" );
     QVERIFY( track );
-    QCOMPARE( track->labels(), newLabels.toSet() );
+    QCOMPARE( track->labels(), QSet<QString> ( newLabels.begin(), newLabels.end() ) );
     verifyEqualExcept( data, track, Meta::valLabel );
 }
